==> allure-report-data-1.4.7-sources.jar: ru/yandex/qatools/allure/data/utils/PluginUtils.java <==
package ru.yandex.qatools.allure.data.utils;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public final class PluginUtils
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
public static final java.lang.String DEFAULT_FEATURE = "Without feature";
public static final java.lang.String DEFAULT_STORY = "Without story";
public static final java.lang.String DEFAULT_HOST = "default";
public static final java.lang.String DEFAULT_THREAD = "default";
public PluginUtils
() {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public static  java.lang.Object getTime(ru.yandex.qatools.allure.model.Step step) { return null;}
public static  java.lang.Object getSuiteName(ru.yandex.qatools.allure.model.TestCaseResult testCase) { return null;}
public static  java.lang.Object getSuiteTitle(ru.yandex.qatools.allure.model.TestCaseResult testCase) { return null;}
public static  java.lang.Object getConvertedDescription(ru.yandex.qatools.allure.model.TestCaseResult testCase) { return null;}
public static  java.lang.Object getTime(ru.yandex.qatools.allure.model.TestCaseResult testCase) { return null;}
public static  java.lang.Object getTestId(ru.yandex.qatools.allure.model.TestCaseResult testCase) { return null;}
public static  java.lang.Object getIssues(ru.yandex.qatools.allure.model.TestCaseResult testCase) { return null;}
public static  java.lang.Object getSeverity(ru.yandex.qatools.allure.model.TestCaseResult testCase) { return null;}
public static  java.lang.Object getLabelValue(ru.yandex.qatools.allure.model.TestCaseResult testCase, ru.yandex.qatools.allure.model.LabelName name) { return null;}
public static  java.lang.Object getLabelValue(ru.yandex.qatools.allure.model.TestCaseResult testCase, java.lang.String name) { return null;}
public static  java.lang.Object getLabelValues(ru.yandex.qatools.allure.model.TestCaseResult testCase, ru.yandex.qatools.allure.model.LabelName name) { return null;}
public static  java.lang.Object toInfo(ru.yandex.qatools.allure.data.AllureTestCase testCase) { return null;}
public static  java.lang.Object getThreadValue(ru.yandex.qatools.allure.data.AllureTestCase testCase) { return null;}
public static  java.lang.Object getHostValue(ru.yandex.qatools.allure.data.AllureTestCase testCase) { return null;}
public static  java.lang.Object getStoryValues(ru.yandex.qatools.allure.data.AllureTestCase testCase) { return null;}
public static  java.lang.Object getFeatureValues(ru.yandex.qatools.allure.data.AllureTestCase testCase) { return null;}
public static  java.lang.Object getLabelValue(ru.yandex.qatools.allure.data.AllureTestCase testCase, ru.yandex.qatools.allure.model.LabelName name) { return null;}
public static  java.lang.Object getLabelValues(ru.yandex.qatools.allure.data.AllureTestCase testCase, ru.yandex.qatools.allure.model.LabelName name) { return null;}
public static  java.lang.Object update(ru.yandex.qatools.allure.data.Time first, ru.yandex.qatools.allure.data.Time second) { return null;}
public static  java.lang.Object update(ru.yandex.qatools.allure.data.Statistic stats, ru.yandex.qatools.allure.model.Status status) { return null;}
public static  java.lang.Object eq(ru.yandex.qatools.allure.data.Statistic stats, ru.yandex.qatools.allure.data.Statistic other) { return null;}
public static  java.lang.Object copy(java.lang.Object from, java.lang.Object to) { return null;}
public static <T> T clone(T from) { return null;}
}

==> allure-report-data-1.4.9-sources.jar: ru/yandex/qatools/allure/data/utils/PluginUtils.java <==
package ru.yandex.qatools.allure.data.utils;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public final class PluginUtils
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
public static final java.lang.String DEFAULT_FEATURE = "Without feature";
public static final java.lang.String DEFAULT_STORY = "Without story";
public static final java.lang.String DEFAULT_HOST = "default";
public static final java.lang.String DEFAULT_THREAD = "default";
public PluginUtils
() {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public static  java.lang.Object getTime(ru.yandex.qatools.allure.model.Step step) { return null;}
public static  java.lang.Object getSuiteName(ru.yandex.qatools.allure.model.TestCaseResult testCase) { return null;}
public static  java.lang.Object getSuiteTitle(ru.yandex.qatools.allure.model.TestCaseResult testCase) { return null;}
public static  java.lang.Object getConvertedDescription(ru.yandex.qatools.allure.model.TestCaseResult testCase) { return null;}
public static  java.lang.Object getTime(ru.yandex.qatools.allure.model.TestCaseResult testCase) { return null;}
public static  java.lang.Object getTestId(ru.yandex.qatools.allure.model.TestCaseResult testCase) { return null;}
public static  java.lang.Object getIssues(ru.yandex.qatools.allure.model.TestCaseResult testCase) { return null;}
public static  java.lang.Object getSeverity(ru.yandex.qatools.allure.model.TestCaseResult testCase) { return null;}
public static  java.lang.Object getLabelValue(ru.yandex.qatools.allure.model.TestCaseResult testCase, ru.yandex.qatools.allure.model.LabelName name) { return null;}
public static  java.lang.Object getLabelValue(ru.yandex.qatools.allure.model.TestCaseResult testCase, java.lang.String name) { return null;}
public static  java.lang.Object getLabelValues(ru.yandex.qatools.allure.model.TestCaseResult testCase, ru.yandex.qatools.allure.model.LabelName name) { return null;}
public static  java.lang.Object toInfo(ru.yandex.qatools.allure.data.AllureTestCase testCase) { return null;}
public static  java.lang.Object getThreadValue(ru.yandex.qatools.allure.data.AllureTestCase testCase) { return null;}
public static  java.lang.Object getHostValue(ru.yandex.qatools.allure.data.AllureTestCase testCase) { return null;}
public static  java.lang.Object getStoryValues(ru.yandex.qatools.allure.data.AllureTestCase testCase) { return null;}
public static  java.lang.Object getFeatureValues(ru.yandex.qatools.allure.data.AllureTestCase testCase) { return null;}
public static  java.lang.Object getLabelValue(ru.yandex.qatools.allure.data.AllureTestCase testCase, ru.yandex.qatools.allure.model.LabelName name) { return null;}
public static  java.lang.Object getLabelValues(ru.yandex.qatools.allure.data.AllureTestCase testCase, ru.yandex.qatools.allure.model.LabelName name) { return null;}
public static  java.lang.Object update(ru.yandex.qatools.allure.data.Time first, ru.yandex.qatools.allure.data.Time second) { return null;}
public static  java.lang.Object update(ru.yandex.qatools.allure.data.Statistic stats, ru.yandex.qatools.allure.model.Status status) { return null;}
public static <T> boolean eq(T stats, T other) { return false;}
public static  java.lang.Object copy(java.lang.Object from, java.lang.Object to) { return null;}
public static <T> T clone(T from) { return null;}
}
